summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/cpu/upd7725/upd7725.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/cpu/upd7725/upd7725.h')
-rw-r--r--src/devices/cpu/upd7725/upd7725.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/src/devices/cpu/upd7725/upd7725.h b/src/devices/cpu/upd7725/upd7725.h
index 481c6e59585..3630ef5f4ca 100644
--- a/src/devices/cpu/upd7725/upd7725.h
+++ b/src/devices/cpu/upd7725/upd7725.h
@@ -191,8 +191,11 @@ private:
void exec_ld(uint32_t opcode);
int m_icount;
- int m_irq; // old irq line state, for detecting rising edges.
-
+ bool m_irq; // old irq line state, for detecting rising edges.
+ // m_irq_firing: if an irq has fired; 0 = not fired or has already finished firing
+ // 1 = next opcode is the first half of int firing 'NOP+push pc'
+ // 2 = next opcode is the second half of int firing 'JMP 0100'
+ int m_irq_firing;
address_space *m_program, *m_data;
direct_read_data *m_direct;